# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_peers.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_peers.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013client_peer'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_peers.proto\"\x87\x01\n\x15\x43lientPeersGetRequest\x12-\n\x06status\x18\x01 \x01(\x0e\x32\x1d.ClientPeersGetRequest.Status\"?\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\r\n\tMALICIOUS\x10\x01\x12\x0e\n\nMALICIOUS1\x10\x02\x12\x0e\n\nMALICIOUS2\x10\x03\"\x86\x01\n\x16\x43lientPeersGetResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.ClientPeersGetResponse.Status\x12\r\n\x05peers\x18\x02 \x03(\t\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"\x8f\x01\n\x19\x43lientPeersControlRequest\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .ClientPeersControlRequest.Modes\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x0c\n\x04peer\x18\x03 \x01(\t\"#\n\x05Modes\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x08\n\x04INFO\x10\x02\"{\n\x1a\x43lientPeersControlResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ClientPeersControlResponse.Status\x12\x0c\n\x04info\x18\x02 \x01(\t\"\x1b\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x42&\n\x15sawtooth.sdk.protobufP\x01Z\x0b\x63lient_peerb\x06proto3')
)



_CLIENTPEERSGETREQUEST_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientPeersGetRequest.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS1', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS2', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=112,
  serialized_end=175,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSGETREQUEST_STATUS)

_CLIENTPEERSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientPeersGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=267,
  serialized_end=312,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSGETRESPONSE_STATUS)

_CLIENTPEERSCONTROLREQUEST_MODES = _descriptor.EnumDescriptor(
  name='Modes',
  full_name='ClientPeersControlRequest.Modes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=423,
  serialized_end=458,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSCONTROLREQUEST_MODES)

_CLIENTPEERSCONTROLRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientPeersControlResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=556,
  serialized_end=583,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSCONTROLRESPONSE_STATUS)


_CLIENTPEERSGETREQUEST = _descriptor.Descriptor(
  name='ClientPeersGetRequest',
  full_name='ClientPeersGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientPeersGetRequest.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSGETREQUEST_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=175,
)


_CLIENTPEERSGETRESPONSE = _descriptor.Descriptor(
  name='ClientPeersGetResponse',
  full_name='ClientPeersGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientPeersGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers', full_name='ClientPeersGetResponse.peers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=312,
)


_CLIENTPEERSCONTROLREQUEST = _descriptor.Descriptor(
  name='ClientPeersControlRequest',
  full_name='ClientPeersControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='ClientPeersControlRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='ClientPeersControlRequest.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='ClientPeersControlRequest.peer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSCONTROLREQUEST_MODES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=458,
)


_CLIENTPEERSCONTROLRESPONSE = _descriptor.Descriptor(
  name='ClientPeersControlResponse',
  full_name='ClientPeersControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientPeersControlResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='ClientPeersControlResponse.info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSCONTROLRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=583,
)

_CLIENTPEERSGETREQUEST.fields_by_name['status'].enum_type = _CLIENTPEERSGETREQUEST_STATUS
_CLIENTPEERSGETREQUEST_STATUS.containing_type = _CLIENTPEERSGETREQUEST
_CLIENTPEERSGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTPEERSGETRESPONSE_STATUS
_CLIENTPEERSGETRESPONSE_STATUS.containing_type = _CLIENTPEERSGETRESPONSE
_CLIENTPEERSCONTROLREQUEST.fields_by_name['mode'].enum_type = _CLIENTPEERSCONTROLREQUEST_MODES
_CLIENTPEERSCONTROLREQUEST_MODES.containing_type = _CLIENTPEERSCONTROLREQUEST
_CLIENTPEERSCONTROLRESPONSE.fields_by_name['status'].enum_type = _CLIENTPEERSCONTROLRESPONSE_STATUS
_CLIENTPEERSCONTROLRESPONSE_STATUS.containing_type = _CLIENTPEERSCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['ClientPeersGetRequest'] = _CLIENTPEERSGETREQUEST
DESCRIPTOR.message_types_by_name['ClientPeersGetResponse'] = _CLIENTPEERSGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientPeersControlRequest'] = _CLIENTPEERSCONTROLREQUEST
DESCRIPTOR.message_types_by_name['ClientPeersControlResponse'] = _CLIENTPEERSCONTROLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientPeersGetRequest = _reflection.GeneratedProtocolMessageType('ClientPeersGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersGetRequest)
  ))
_sym_db.RegisterMessage(ClientPeersGetRequest)

ClientPeersGetResponse = _reflection.GeneratedProtocolMessageType('ClientPeersGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersGetResponse)
  ))
_sym_db.RegisterMessage(ClientPeersGetResponse)

ClientPeersControlRequest = _reflection.GeneratedProtocolMessageType('ClientPeersControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSCONTROLREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersControlRequest)
  ))
_sym_db.RegisterMessage(ClientPeersControlRequest)

ClientPeersControlResponse = _reflection.GeneratedProtocolMessageType('ClientPeersControlResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSCONTROLRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersControlResponse)
  ))
_sym_db.RegisterMessage(ClientPeersControlResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
