# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_heads.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_heads.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013client_head'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_heads.proto\"(\n\x15\x43lientHeadsGetRequest\x12\x0f\n\x07head_id\x18\x01 \x01(\t\"\x86\x01\n\x16\x43lientHeadsGetResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.ClientHeadsGetResponse.Status\x12\r\n\x05heads\x18\x02 \x03(\t\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"$\n\x12\x44\x61gGraphGetRequest\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\"\x80\x01\n\x13\x44\x61gGraphGetResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.DagGraphGetResponse.Status\x12\r\n\x05graph\x18\x02 \x01(\t\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x42&\n\x15sawtooth.sdk.protobufP\x01Z\x0b\x63lient_headb\x06proto3')
)



_CLIENTHEADSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientHeadsGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=171,
  serialized_end=216,
)
_sym_db.RegisterEnumDescriptor(_CLIENTHEADSGETRESPONSE_STATUS)

_DAGGRAPHGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='DagGraphGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=171,
  serialized_end=216,
)
_sym_db.RegisterEnumDescriptor(_DAGGRAPHGETRESPONSE_STATUS)


_CLIENTHEADSGETREQUEST = _descriptor.Descriptor(
  name='ClientHeadsGetRequest',
  full_name='ClientHeadsGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head_id', full_name='ClientHeadsGetRequest.head_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=79,
)


_CLIENTHEADSGETRESPONSE = _descriptor.Descriptor(
  name='ClientHeadsGetResponse',
  full_name='ClientHeadsGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientHeadsGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heads', full_name='ClientHeadsGetResponse.heads', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTHEADSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=216,
)


_DAGGRAPHGETREQUEST = _descriptor.Descriptor(
  name='DagGraphGetRequest',
  full_name='DagGraphGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='DagGraphGetRequest.format', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=254,
)


_DAGGRAPHGETRESPONSE = _descriptor.Descriptor(
  name='DagGraphGetResponse',
  full_name='DagGraphGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='DagGraphGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph', full_name='DagGraphGetResponse.graph', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DAGGRAPHGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=385,
)

_CLIENTHEADSGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTHEADSGETRESPONSE_STATUS
_CLIENTHEADSGETRESPONSE_STATUS.containing_type = _CLIENTHEADSGETRESPONSE
_DAGGRAPHGETRESPONSE.fields_by_name['status'].enum_type = _DAGGRAPHGETRESPONSE_STATUS
_DAGGRAPHGETRESPONSE_STATUS.containing_type = _DAGGRAPHGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientHeadsGetRequest'] = _CLIENTHEADSGETREQUEST
DESCRIPTOR.message_types_by_name['ClientHeadsGetResponse'] = _CLIENTHEADSGETRESPONSE
DESCRIPTOR.message_types_by_name['DagGraphGetRequest'] = _DAGGRAPHGETREQUEST
DESCRIPTOR.message_types_by_name['DagGraphGetResponse'] = _DAGGRAPHGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientHeadsGetRequest = _reflection.GeneratedProtocolMessageType('ClientHeadsGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTHEADSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:ClientHeadsGetRequest)
  ))
_sym_db.RegisterMessage(ClientHeadsGetRequest)

ClientHeadsGetResponse = _reflection.GeneratedProtocolMessageType('ClientHeadsGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTHEADSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:ClientHeadsGetResponse)
  ))
_sym_db.RegisterMessage(ClientHeadsGetResponse)

DagGraphGetRequest = _reflection.GeneratedProtocolMessageType('DagGraphGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _DAGGRAPHGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:DagGraphGetRequest)
  ))
_sym_db.RegisterMessage(DagGraphGetRequest)

DagGraphGetResponse = _reflection.GeneratedProtocolMessageType('DagGraphGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _DAGGRAPHGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:DagGraphGetResponse)
  ))
_sym_db.RegisterMessage(DagGraphGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
