# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/network.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/network.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013network_pb2'),
  serialized_pb=_b('\n\x1e\x64gt_sdk/protobuf/network.proto\"\x13\n\x11\x44isconnectMessage\"\xd9\x01\n\x13PeerRegisterRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x18\n\x10protocol_version\x18\x02 \x01(\r\x12/\n\x04mode\x18\x03 \x01(\x0e\x32!.PeerRegisterRequest.RegisterMode\x12\x0b\n\x03pid\x18\x04 \x01(\r\x12\x11\n\tcomponent\x18\x05 \x01(\t\x12\x10\n\x08\x65xtpoint\x18\x06 \x01(\t\x12\x0b\n\x03hid\x18\x07 \x01(\t\"&\n\x0cRegisterMode\x12\x0c\n\x08REGISTER\x10\x00\x12\x08\n\x04SYNC\x10\x01\"\x17\n\x15PeerUnregisterRequest\"r\n\x0fGetPeersRequest\x12\x0f\n\x07peer_id\x18\x01 \x01(\x0c\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x0f\n\x07\x63luster\x18\x03 \x01(\t\x12\x0b\n\x03KYC\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x06 \x01(\t\"\x85\x02\n\x10GetPeersResponse\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32 .GetPeersResponse.GetPeersStatus\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x16\n\x0epeer_endpoints\x18\x03 \x03(\t\"\x95\x01\n\x0eGetPeersStatus\x12\x06\n\x02OK\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08REDIRECT\x10\x02\x12\n\n\x06\x44\x45NIED\x10\x03\x12\n\n\x06JOINED\x10\x04\x12\x0c\n\x08\x44YNPEERS\x10\x05\x12\x0b\n\x07NOSPACE\x10\x06\x12\x0b\n\x07WAITING\x10\x07\x12\x0c\n\x08PEERSTAT\x10\x08\x12\x12\n\x0eNOT_VALID_CERT\x10\t\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xc1\x01\n\rGossipMessage\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x30\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x1a.GossipMessage.ContentType\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"W\n\x0b\x43ontentType\x12\x16\n\x12\x43ONTENT_TYPE_UNSET\x10\x00\x12\t\n\x05\x42LOCK\x10\x01\x12\t\n\x05\x42\x41TCH\x10\x02\x12\x0b\n\x07\x42\x41TCHES\x10\x03\x12\r\n\tENDPOINTS\x10\x04\"\x92\x01\n\x16NetworkAcknowledgement\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.NetworkAcknowledgement.Status\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x0c\n\x04sync\x18\x03 \x01(\x08\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"K\n\x12GossipBlockRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"4\n\x13GossipBlockResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x0c\n\x04nest\x18\x02 \x01(\x08\"&\n\x13GossipBatchResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"N\n\x1bGossipBatchByBatchIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"U\n!GossipBatchByTransactionIdRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"R\n\x16GossipConsensusMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x11\n\tsender_id\x18\x02 \x01(\x0c\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"1\n\x0c\x45ndpointItem\x12\x0f\n\x07peer_id\x18\x01 \x01(\x0c\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\"0\n\x0c\x45ndpointList\x12 \n\tendpoints\x18\x01 \x03(\x0b\x32\r.EndpointItemB&\n\x15sawtooth.sdk.protobufP\x01Z\x0bnetwork_pb2b\x06proto3')
)



_PEERREGISTERREQUEST_REGISTERMODE = _descriptor.EnumDescriptor(
  name='RegisterMode',
  full_name='PeerRegisterRequest.RegisterMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REGISTER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYNC', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=235,
  serialized_end=273,
)
_sym_db.RegisterEnumDescriptor(_PEERREGISTERREQUEST_REGISTERMODE)

_GETPEERSRESPONSE_GETPEERSSTATUS = _descriptor.EnumDescriptor(
  name='GetPeersStatus',
  full_name='GetPeersResponse.GetPeersStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDIRECT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DENIED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOINED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNPEERS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOSPACE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAITING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PEERSTAT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_VALID_CERT', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=529,
  serialized_end=678,
)
_sym_db.RegisterEnumDescriptor(_GETPEERSRESPONSE_GETPEERSSTATUS)

_GOSSIPMESSAGE_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='GossipMessage.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTENT_TYPE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BATCH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BATCHES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENDPOINTS', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=818,
  serialized_end=905,
)
_sym_db.RegisterEnumDescriptor(_GOSSIPMESSAGE_CONTENTTYPE)

_NETWORKACKNOWLEDGEMENT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='NetworkAcknowledgement.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1009,
  serialized_end=1054,
)
_sym_db.RegisterEnumDescriptor(_NETWORKACKNOWLEDGEMENT_STATUS)


_DISCONNECTMESSAGE = _descriptor.Descriptor(
  name='DisconnectMessage',
  full_name='DisconnectMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=53,
)


_PEERREGISTERREQUEST = _descriptor.Descriptor(
  name='PeerRegisterRequest',
  full_name='PeerRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='PeerRegisterRequest.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='PeerRegisterRequest.protocol_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='PeerRegisterRequest.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='PeerRegisterRequest.pid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='PeerRegisterRequest.component', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extpoint', full_name='PeerRegisterRequest.extpoint', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hid', full_name='PeerRegisterRequest.hid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PEERREGISTERREQUEST_REGISTERMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=273,
)


_PEERUNREGISTERREQUEST = _descriptor.Descriptor(
  name='PeerUnregisterRequest',
  full_name='PeerUnregisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=298,
)


_GETPEERSREQUEST = _descriptor.Descriptor(
  name='GetPeersRequest',
  full_name='GetPeersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='GetPeersRequest.peer_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='GetPeersRequest.endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='GetPeersRequest.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='KYC', full_name='GetPeersRequest.KYC', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network', full_name='GetPeersRequest.network', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch', full_name='GetPeersRequest.batch', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=414,
)


_GETPEERSRESPONSE = _descriptor.Descriptor(
  name='GetPeersResponse',
  full_name='GetPeersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='GetPeersResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='GetPeersResponse.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_endpoints', full_name='GetPeersResponse.peer_endpoints', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETPEERSRESPONSE_GETPEERSSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=678,
)


_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=693,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=709,
)


_GOSSIPMESSAGE = _descriptor.Descriptor(
  name='GossipMessage',
  full_name='GossipMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='GossipMessage.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='GossipMessage.content_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipMessage.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GOSSIPMESSAGE_CONTENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=905,
)


_NETWORKACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='NetworkAcknowledgement',
  full_name='NetworkAcknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='NetworkAcknowledgement.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='NetworkAcknowledgement.pid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync', full_name='NetworkAcknowledgement.sync', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORKACKNOWLEDGEMENT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=1054,
)


_GOSSIPBLOCKREQUEST = _descriptor.Descriptor(
  name='GossipBlockRequest',
  full_name='GossipBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='GossipBlockRequest.block_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='GossipBlockRequest.nonce', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipBlockRequest.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1131,
)


_GOSSIPBLOCKRESPONSE = _descriptor.Descriptor(
  name='GossipBlockResponse',
  full_name='GossipBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='GossipBlockResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nest', full_name='GossipBlockResponse.nest', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1185,
)


_GOSSIPBATCHRESPONSE = _descriptor.Descriptor(
  name='GossipBatchResponse',
  full_name='GossipBatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='GossipBatchResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1225,
)


_GOSSIPBATCHBYBATCHIDREQUEST = _descriptor.Descriptor(
  name='GossipBatchByBatchIdRequest',
  full_name='GossipBatchByBatchIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='GossipBatchByBatchIdRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='GossipBatchByBatchIdRequest.nonce', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipBatchByBatchIdRequest.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1305,
)


_GOSSIPBATCHBYTRANSACTIONIDREQUEST = _descriptor.Descriptor(
  name='GossipBatchByTransactionIdRequest',
  full_name='GossipBatchByTransactionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='GossipBatchByTransactionIdRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='GossipBatchByTransactionIdRequest.nonce', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipBatchByTransactionIdRequest.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1392,
)


_GOSSIPCONSENSUSMESSAGE = _descriptor.Descriptor(
  name='GossipConsensusMessage',
  full_name='GossipConsensusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='GossipConsensusMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='GossipConsensusMessage.sender_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipConsensusMessage.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1476,
)


_ENDPOINTITEM = _descriptor.Descriptor(
  name='EndpointItem',
  full_name='EndpointItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='EndpointItem.peer_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='EndpointItem.endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1527,
)


_ENDPOINTLIST = _descriptor.Descriptor(
  name='EndpointList',
  full_name='EndpointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='EndpointList.endpoints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1577,
)

_PEERREGISTERREQUEST.fields_by_name['mode'].enum_type = _PEERREGISTERREQUEST_REGISTERMODE
_PEERREGISTERREQUEST_REGISTERMODE.containing_type = _PEERREGISTERREQUEST
_GETPEERSRESPONSE.fields_by_name['status'].enum_type = _GETPEERSRESPONSE_GETPEERSSTATUS
_GETPEERSRESPONSE_GETPEERSSTATUS.containing_type = _GETPEERSRESPONSE
_GOSSIPMESSAGE.fields_by_name['content_type'].enum_type = _GOSSIPMESSAGE_CONTENTTYPE
_GOSSIPMESSAGE_CONTENTTYPE.containing_type = _GOSSIPMESSAGE
_NETWORKACKNOWLEDGEMENT.fields_by_name['status'].enum_type = _NETWORKACKNOWLEDGEMENT_STATUS
_NETWORKACKNOWLEDGEMENT_STATUS.containing_type = _NETWORKACKNOWLEDGEMENT
_ENDPOINTLIST.fields_by_name['endpoints'].message_type = _ENDPOINTITEM
DESCRIPTOR.message_types_by_name['DisconnectMessage'] = _DISCONNECTMESSAGE
DESCRIPTOR.message_types_by_name['PeerRegisterRequest'] = _PEERREGISTERREQUEST
DESCRIPTOR.message_types_by_name['PeerUnregisterRequest'] = _PEERUNREGISTERREQUEST
DESCRIPTOR.message_types_by_name['GetPeersRequest'] = _GETPEERSREQUEST
DESCRIPTOR.message_types_by_name['GetPeersResponse'] = _GETPEERSRESPONSE
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['GossipMessage'] = _GOSSIPMESSAGE
DESCRIPTOR.message_types_by_name['NetworkAcknowledgement'] = _NETWORKACKNOWLEDGEMENT
DESCRIPTOR.message_types_by_name['GossipBlockRequest'] = _GOSSIPBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GossipBlockResponse'] = _GOSSIPBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GossipBatchResponse'] = _GOSSIPBATCHRESPONSE
DESCRIPTOR.message_types_by_name['GossipBatchByBatchIdRequest'] = _GOSSIPBATCHBYBATCHIDREQUEST
DESCRIPTOR.message_types_by_name['GossipBatchByTransactionIdRequest'] = _GOSSIPBATCHBYTRANSACTIONIDREQUEST
DESCRIPTOR.message_types_by_name['GossipConsensusMessage'] = _GOSSIPCONSENSUSMESSAGE
DESCRIPTOR.message_types_by_name['EndpointItem'] = _ENDPOINTITEM
DESCRIPTOR.message_types_by_name['EndpointList'] = _ENDPOINTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DisconnectMessage = _reflection.GeneratedProtocolMessageType('DisconnectMessage', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTMESSAGE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:DisconnectMessage)
  ))
_sym_db.RegisterMessage(DisconnectMessage)

PeerRegisterRequest = _reflection.GeneratedProtocolMessageType('PeerRegisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PEERREGISTERREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PeerRegisterRequest)
  ))
_sym_db.RegisterMessage(PeerRegisterRequest)

PeerUnregisterRequest = _reflection.GeneratedProtocolMessageType('PeerUnregisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PEERUNREGISTERREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PeerUnregisterRequest)
  ))
_sym_db.RegisterMessage(PeerUnregisterRequest)

GetPeersRequest = _reflection.GeneratedProtocolMessageType('GetPeersRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPEERSREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GetPeersRequest)
  ))
_sym_db.RegisterMessage(GetPeersRequest)

GetPeersResponse = _reflection.GeneratedProtocolMessageType('GetPeersResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPEERSRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GetPeersResponse)
  ))
_sym_db.RegisterMessage(GetPeersResponse)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), dict(
  DESCRIPTOR = _PINGREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PingRequest)
  ))
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), dict(
  DESCRIPTOR = _PINGRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PingResponse)
  ))
_sym_db.RegisterMessage(PingResponse)

GossipMessage = _reflection.GeneratedProtocolMessageType('GossipMessage', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPMESSAGE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipMessage)
  ))
_sym_db.RegisterMessage(GossipMessage)

NetworkAcknowledgement = _reflection.GeneratedProtocolMessageType('NetworkAcknowledgement', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKACKNOWLEDGEMENT,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:NetworkAcknowledgement)
  ))
_sym_db.RegisterMessage(NetworkAcknowledgement)

GossipBlockRequest = _reflection.GeneratedProtocolMessageType('GossipBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBlockRequest)
  ))
_sym_db.RegisterMessage(GossipBlockRequest)

GossipBlockResponse = _reflection.GeneratedProtocolMessageType('GossipBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBlockResponse)
  ))
_sym_db.RegisterMessage(GossipBlockResponse)

GossipBatchResponse = _reflection.GeneratedProtocolMessageType('GossipBatchResponse', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBATCHRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBatchResponse)
  ))
_sym_db.RegisterMessage(GossipBatchResponse)

GossipBatchByBatchIdRequest = _reflection.GeneratedProtocolMessageType('GossipBatchByBatchIdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBATCHBYBATCHIDREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBatchByBatchIdRequest)
  ))
_sym_db.RegisterMessage(GossipBatchByBatchIdRequest)

GossipBatchByTransactionIdRequest = _reflection.GeneratedProtocolMessageType('GossipBatchByTransactionIdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBATCHBYTRANSACTIONIDREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBatchByTransactionIdRequest)
  ))
_sym_db.RegisterMessage(GossipBatchByTransactionIdRequest)

GossipConsensusMessage = _reflection.GeneratedProtocolMessageType('GossipConsensusMessage', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPCONSENSUSMESSAGE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipConsensusMessage)
  ))
_sym_db.RegisterMessage(GossipConsensusMessage)

EndpointItem = _reflection.GeneratedProtocolMessageType('EndpointItem', (_message.Message,), dict(
  DESCRIPTOR = _ENDPOINTITEM,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:EndpointItem)
  ))
_sym_db.RegisterMessage(EndpointItem)

EndpointList = _reflection.GeneratedProtocolMessageType('EndpointList', (_message.Message,), dict(
  DESCRIPTOR = _ENDPOINTLIST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:EndpointList)
  ))
_sym_db.RegisterMessage(EndpointList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
