# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/bgx_validator_registry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/bgx_validator_registry.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\030sawtooth.config.protobufP\001'),
  serialized_pb=_b('\n-dgt_sdk/protobuf/bgx_validator_registry.proto\"w\n\x10\x42gxValidatorInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\x12#\n\x0bsignup_info\x18\x04 \x01(\x0b\x32\x0e.BgxSignUpInfo\x12\x16\n\x0etransaction_id\x18\x05 \x01(\t\"N\n\rBgxSignUpInfo\x12\x17\n\x0fpbft_public_key\x18\x01 \x01(\t\x12\x15\n\ranti_sybil_id\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\t\"_\n\x0f\x42gxValidatorMap\x12\'\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x16.BgxValidatorMap.Entry\x1a#\n\x05\x45ntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"x\n\x1b\x42gxValidatorRegistryPayload\x12\x0c\n\x04verb\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04node\x18\x04 \x01(\t\x12#\n\x0bsignup_info\x18\x05 \x01(\x0b\x32\x0e.BgxSignUpInfoB\x1c\n\x18sawtooth.config.protobufP\x01\x62\x06proto3')
)




_BGXVALIDATORINFO = _descriptor.Descriptor(
  name='BgxValidatorInfo',
  full_name='BgxValidatorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='BgxValidatorInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='BgxValidatorInfo.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node', full_name='BgxValidatorInfo.node', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signup_info', full_name='BgxValidatorInfo.signup_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='BgxValidatorInfo.transaction_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=168,
)


_BGXSIGNUPINFO = _descriptor.Descriptor(
  name='BgxSignUpInfo',
  full_name='BgxSignUpInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pbft_public_key', full_name='BgxSignUpInfo.pbft_public_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anti_sybil_id', full_name='BgxSignUpInfo.anti_sybil_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='BgxSignUpInfo.nonce', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=248,
)


_BGXVALIDATORMAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='BgxValidatorMap.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='BgxValidatorMap.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='BgxValidatorMap.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=345,
)

_BGXVALIDATORMAP = _descriptor.Descriptor(
  name='BgxValidatorMap',
  full_name='BgxValidatorMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='BgxValidatorMap.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BGXVALIDATORMAP_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=345,
)


_BGXVALIDATORREGISTRYPAYLOAD = _descriptor.Descriptor(
  name='BgxValidatorRegistryPayload',
  full_name='BgxValidatorRegistryPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='verb', full_name='BgxValidatorRegistryPayload.verb', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='BgxValidatorRegistryPayload.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='BgxValidatorRegistryPayload.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node', full_name='BgxValidatorRegistryPayload.node', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signup_info', full_name='BgxValidatorRegistryPayload.signup_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=467,
)

_BGXVALIDATORINFO.fields_by_name['signup_info'].message_type = _BGXSIGNUPINFO
_BGXVALIDATORMAP_ENTRY.containing_type = _BGXVALIDATORMAP
_BGXVALIDATORMAP.fields_by_name['entries'].message_type = _BGXVALIDATORMAP_ENTRY
_BGXVALIDATORREGISTRYPAYLOAD.fields_by_name['signup_info'].message_type = _BGXSIGNUPINFO
DESCRIPTOR.message_types_by_name['BgxValidatorInfo'] = _BGXVALIDATORINFO
DESCRIPTOR.message_types_by_name['BgxSignUpInfo'] = _BGXSIGNUPINFO
DESCRIPTOR.message_types_by_name['BgxValidatorMap'] = _BGXVALIDATORMAP
DESCRIPTOR.message_types_by_name['BgxValidatorRegistryPayload'] = _BGXVALIDATORREGISTRYPAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BgxValidatorInfo = _reflection.GeneratedProtocolMessageType('BgxValidatorInfo', (_message.Message,), dict(
  DESCRIPTOR = _BGXVALIDATORINFO,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxValidatorInfo)
  ))
_sym_db.RegisterMessage(BgxValidatorInfo)

BgxSignUpInfo = _reflection.GeneratedProtocolMessageType('BgxSignUpInfo', (_message.Message,), dict(
  DESCRIPTOR = _BGXSIGNUPINFO,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxSignUpInfo)
  ))
_sym_db.RegisterMessage(BgxSignUpInfo)

BgxValidatorMap = _reflection.GeneratedProtocolMessageType('BgxValidatorMap', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _BGXVALIDATORMAP_ENTRY,
    __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
    # @@protoc_insertion_point(class_scope:BgxValidatorMap.Entry)
    ))
  ,
  DESCRIPTOR = _BGXVALIDATORMAP,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxValidatorMap)
  ))
_sym_db.RegisterMessage(BgxValidatorMap)
_sym_db.RegisterMessage(BgxValidatorMap.Entry)

BgxValidatorRegistryPayload = _reflection.GeneratedProtocolMessageType('BgxValidatorRegistryPayload', (_message.Message,), dict(
  DESCRIPTOR = _BGXVALIDATORREGISTRYPAYLOAD,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxValidatorRegistryPayload)
  ))
_sym_db.RegisterMessage(BgxValidatorRegistryPayload)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
